@@ -1,4 +1,3 @@
-import datetime
 import uuid
 
 import requests
@@ -27,6 +26,7 @@ from buybackprogram.notes import (
     note_no_price_data,
     note_npc_price,
     note_price_dencity_tax,
+    note_raw_price_used,
     note_refined_price_used,
     note_unpublished_item,
 )
@@ -141,13 +141,20 @@ def get_price_dencity_tax(program, item_value, item_volume, item_quantity):
 
         if item_isk_dencity < program.price_dencity_treshold and item_isk_dencity:
             logger.debug(
-                "Isk dencity under threshold value, applying extra taxes of %s"
-                % program.price_dencity_tax
+                "Isk dencity %s is under threshold value %s, applying extra taxes of %s"
+                % (
+                    item_isk_dencity,
+                    program.price_dencity_treshold,
+                    program.price_dencity_tax,
+                )
             )
 
             return program.price_dencity_tax
         else:
-            logger.debug("Isk dencity above threshold value, no extra taxes added")
+            logger.debug(
+                "Isk dencity %s is above threshold value %s, no extra taxes added"
+                % (item_isk_dencity, program.price_dencity_treshold)
+            )
             return False
     else:
         return False
@@ -197,7 +204,12 @@ def get_item_prices(item_type, name, quantity, program):
     if not item_disallowed:
 
         # If raw ore value should not be taken into account
-        if not program.use_raw_ore_value and is_ore(item_type.eve_group.id):
+        if (
+            is_ore(item_type.eve_group.id) or is_moon_ore(item_type.eve_group.id)
+        ) and not program.use_raw_ore_value:
+
+            logger.debug("Raw price not used for %s" % item_type.name)
+
             item_raw_price = {
                 "id": item_type.id,
                 "quantity": quantity,
@@ -217,7 +229,7 @@ def get_item_prices(item_type, name, quantity, program):
 
         # Check if we should get refined value for the item
         if (
-            is_ore(item_type.eve_group.id) or is_moon_ore(item_type.eve_group.id)
+            (is_ore(item_type.eve_group.id) or is_moon_ore(item_type.eve_group.id))
         ) and program.use_refined_value:
             item_material_price = []
             # Get all refining materials for item
@@ -258,7 +270,7 @@ def get_item_prices(item_type, name, quantity, program):
 
         # Get compressed versions of the ores that are not yet compressed
         if (
-            is_ore(item_type.eve_group.id) or is_moon_ore(item_type.eve_group.id)
+            (is_ore(item_type.eve_group.id) or is_moon_ore(item_type.eve_group.id))
         ) and program.use_compressed_value:
 
             if "Compressed" in name:
@@ -395,12 +407,14 @@ def get_item_values(item_type, item_prices, program):
 
     else:
         raw_item = {
-            "unite_value": False,
+            "unit_value": False,
             "value": False,
             "total_tax": False,
             "raw_value": False,
         }
 
+    logger.debug("Values: Item material price is %s" % item_prices["material_prices"])
+
     # Get values for refined variant
     if item_prices["material_prices"]:
 
@@ -415,6 +429,8 @@ def get_item_values(item_type, item_prices, program):
 
         material_count = len(item_prices["material_prices"])
 
+        item_tax = get_item_tax(program, item_type.id)
+
         for material in item_prices["material_prices"]:
 
             materials = EveType.objects.filter(id=material["id"]).first()
@@ -428,7 +444,6 @@ def get_item_values(item_type, item_prices, program):
                 program, price, materials.volume, quantity
             )
             program_tax = program.tax
-            item_tax = get_item_tax(program, item_type.id)
             refining_rate = program.refining_rate / 100
             tax_multiplier = (100 - (program_tax + item_tax + price_dencity_tax)) / 100
 
@@ -455,7 +470,6 @@ def get_item_values(item_type, item_prices, program):
             r["notes"].append(
                 note_price_dencity_tax(materials.name, price_dencity, price_dencity_tax)
             )
-            r["notes"].append(note_item_specific_tax(materials.name, item_tax))
 
             refined["materials"].append(r)
 
@@ -474,6 +488,10 @@ def get_item_values(item_type, item_prices, program):
             "unit_value": False,
         }
 
+    logger.debug(
+        "Values: Item compression price is %s" % item_prices["compression_prices"]
+    )
+
     # Get values for compressed variant
     if item_prices["compression_prices"]:
 
@@ -486,6 +504,9 @@ def get_item_values(item_type, item_prices, program):
         sell = item_prices["compression_prices"]["sell"]
         price = buy
         price_dencity = price / compressed_version.volume
+
+        logger.debug("Getting price density for compressed variant")
+
         price_dencity_tax = get_price_dencity_tax(
             program, price, compressed_version.volume, quantity
         )
@@ -631,6 +652,9 @@ def get_item_values(item_type, item_prices, program):
         raw_item["is_buy_value"] = True
         tax_value = raw_item["total_tax"]
 
+        if item_prices["has_price_variants"]:
+            item_prices["notes"].append(note_raw_price_used(raw_item["name"]))
+
         item_prices["notes"].append(
             note_price_dencity_tax(
                 raw_item["name"],
@@ -657,18 +681,17 @@ def get_item_values(item_type, item_prices, program):
                     material["price_dencity_tax"],
                 )
             )
-            item_prices["notes"].append(
-                note_item_specific_tax(
-                    material["name"] + " material", material["item_tax"]
-                )
-            )
+
+        item_prices["notes"].append(
+            note_item_specific_tax(raw_item["name"], raw_item["item_tax"])
+        )
 
     elif buy_value == compressed["value"]:
 
         compressed["is_buy_value"] = True
         tax_value = compressed["total_tax"]
 
-        item_prices["notes"].append(note_compressed_price_used(raw_item["name"]))
+        item_prices["notes"].append(note_compressed_price_used(compressed["name"]))
 
         item_prices["notes"].append(
             note_price_dencity_tax(
@@ -678,7 +701,7 @@ def get_item_values(item_type, item_prices, program):
             )
         )
         item_prices["notes"].append(
-            note_item_specific_tax(raw_item["name"], compressed["item_tax"])
+            note_item_specific_tax(compressed["name"], compressed["item_tax"])
         )
     elif buy_value == npc_item["value"]:
 
@@ -829,7 +852,7 @@ def get_tracking_number(
         donation=contract_price_data["total_donation_amount"],
         net_price=round(contract_price_data["contract_net_total"]),
         tracking_number=tracking_number,
-        created_at=datetime.datetime.now(),
+        created_at=timezone.now(),
     )
 
     tracking.save()
